# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import ocvp_type_mapping
missing = Sentinel("Missing")


class SddcClient(object):
    """
    Use this API to manage your [Oracle Cloud VMware Solution](/iaas/Content/VMware/Concepts/ocvsoverview.htm).
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20200501',
            'service_endpoint_template': 'https://ocvps.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        self.base_client = BaseClient("sddc", config, signer, ocvp_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')

    def cancel_downgrade_hcx(self, sddc_id, **kwargs):
        """
        Cancel the pending SDDC downgrade from HCX Enterprise to HCX Advanced


        :param str sddc_id: (required)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations (for example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            may be rejected).

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/cancel_downgrade_hcx.py.html>`__ to see an example of how to use cancel_downgrade_hcx API.
        """
        resource_path = "/sddcs/{sddcId}/actions/cancelDowngradeHcx"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "cancel_downgrade_hcx got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "sddcId": sddc_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def change_sddc_compartment(self, sddc_id, change_sddc_compartment_details, **kwargs):
        """
        Moves an SDDC into a different compartment within the same tenancy. For information
        about moving resources between compartments, see
        `Moving Resources to a Different Compartment`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes


        :param str sddc_id: (required)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.ocvp.models.ChangeSddcCompartmentDetails change_sddc_compartment_details: (required)
            Request to change the compartment of the specified SDDC

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations (for example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            may be rejected).

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/change_sddc_compartment.py.html>`__ to see an example of how to use change_sddc_compartment API.
        """
        resource_path = "/sddcs/{sddcId}/actions/changeCompartment"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id",
            "opc_retry_token"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "change_sddc_compartment got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "sddcId": sddc_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing),
            "opc-retry-token": kwargs.get("opc_retry_token", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_sddc_compartment_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_sddc_compartment_details)

    def create_sddc(self, create_sddc_details, **kwargs):
        """
        Creates an Oracle Cloud VMware Solution software-defined data center (SDDC).

        Use the :class:`WorkRequest` operations to track the
        creation of the SDDC.

        **Important:** You must configure the SDDC's networking resources with the security rules detailed in `Security Rules for Oracle Cloud VMware Solution SDDCs`__. Otherwise, provisioning the SDDC will fail. The rules are based on the requirements set by VMware.

        __ https://docs.cloud.oracle.com/iaas/Content/VMware/Reference/ocvssecurityrules.htm


        :param oci.ocvp.models.CreateSddcDetails create_sddc_details: (required)
            Details for the SDDC.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations (for example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            may be rejected).

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/create_sddc.py.html>`__ to see an example of how to use create_sddc API.
        """
        resource_path = "/sddcs"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_sddc got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_sddc_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_sddc_details)

    def delete_sddc(self, sddc_id, **kwargs):
        """
        Deletes the specified SDDC, along with the other resources that were
        created with the SDDC. For example: the Compute instances, DNS records,
        and so on.

        Use the :class:`WorkRequest` operations to track the
        deletion of the SDDC.


        :param str sddc_id: (required)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/delete_sddc.py.html>`__ to see an example of how to use delete_sddc API.
        """
        resource_path = "/sddcs/{sddcId}"
        method = "DELETE"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_sddc got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "sddcId": sddc_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def downgrade_hcx(self, downgrade_hcx_details, sddc_id, **kwargs):
        """
        Downgrade the specified SDDC from HCX Enterprise to HCX Advanced


        :param oci.ocvp.models.DowngradeHcxDetails downgrade_hcx_details: (required)
            The HCX on-premise license keys to be reserved when downgrade from HCX Enterprise to HCX Advanced.

        :param str sddc_id: (required)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations (for example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            may be rejected).

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/downgrade_hcx.py.html>`__ to see an example of how to use downgrade_hcx API.
        """
        resource_path = "/sddcs/{sddcId}/actions/downgradeHcx"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "downgrade_hcx got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "sddcId": sddc_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=downgrade_hcx_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=downgrade_hcx_details)

    def get_sddc(self, sddc_id, **kwargs):
        """
        Gets the specified SDDC's information.


        :param str sddc_id: (required)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ocvp.models.Sddc`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/get_sddc.py.html>`__ to see an example of how to use get_sddc API.
        """
        resource_path = "/sddcs/{sddcId}"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_sddc got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "sddcId": sddc_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="Sddc")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="Sddc")

    def list_sddcs(self, compartment_id, **kwargs):
        """
        Lists the SDDCs in the specified compartment. The list can be
        filtered by display name or availability domain.


        :param str compartment_id: (required)
            The `OCID`__ of the compartment.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str compute_availability_domain: (optional)
            The name of the availability domain that the Compute instances are running in.

            Example: `Uocm:PHX-AD-1`

        :param str display_name: (optional)
            A filter to return only resources that match the given display name exactly.

        :param int limit: (optional)
            For list pagination. The maximum number of results per page, or items to return in a paginated
            \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str page: (optional)
            For list pagination. The value of the `opc-next-page` response header from the previous \"List\"
            call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str sort_order: (optional)
            The sort order to use, either ascending (`ASC`) or descending (`DESC`). The DISPLAYNAME sort order
            is case sensitive.

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            The field to sort by. You can provide one sort order (`sortOrder`). Default order for
            TIMECREATED is descending. Default order for DISPLAYNAME is ascending. The DISPLAYNAME
            sort order is case sensitive.

            **Note:** In general, some \"List\" operations (for example, `ListInstances`) let you
            optionally filter by availability domain if the scope of the resource type is within a
            single availability domain. If you call one of these \"List\" operations without specifying
            an availability domain, the resources are grouped by availability domain, then sorted.

            Allowed values are: "timeCreated", "displayName"

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param str lifecycle_state: (optional)
            The lifecycle state of the resource.

            Allowed values are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ocvp.models.SddcCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/list_sddcs.py.html>`__ to see an example of how to use list_sddcs API.
        """
        resource_path = "/sddcs"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "compute_availability_domain",
            "display_name",
            "limit",
            "page",
            "sort_order",
            "sort_by",
            "opc_request_id",
            "lifecycle_state"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_sddcs got unknown kwargs: {!r}".format(extra_kwargs))

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        query_params = {
            "compartmentId": compartment_id,
            "computeAvailabilityDomain": kwargs.get("compute_availability_domain", missing),
            "displayName": kwargs.get("display_name", missing),
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing),
            "lifecycleState": kwargs.get("lifecycle_state", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="SddcCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="SddcCollection")

    def list_supported_skus(self, compartment_id, **kwargs):
        """
        Lists supported SKUs. Oracle Cloud Infrastructure VMware Solution supports the following billing interval SKUs:
        HOUR, MONTH, ONE_YEAR, and THREE_YEARS.


        :param str compartment_id: (required)
            The `OCID`__ of the compartment.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param int limit: (optional)
            For list pagination. The maximum number of results per page, or items to return in a paginated
            \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str page: (optional)
            For list pagination. The value of the `opc-next-page` response header from the previous \"List\"
            call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ocvp.models.SupportedSkuSummaryCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/list_supported_skus.py.html>`__ to see an example of how to use list_supported_skus API.
        """
        resource_path = "/supportedSkus"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "limit",
            "page",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_supported_skus got unknown kwargs: {!r}".format(extra_kwargs))

        query_params = {
            "compartmentId": compartment_id,
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="SupportedSkuSummaryCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="SupportedSkuSummaryCollection")

    def list_supported_vmware_software_versions(self, compartment_id, **kwargs):
        """
        Lists the versions of bundled VMware software supported by the Oracle Cloud
        VMware Solution.


        :param str compartment_id: (required)
            The `OCID`__ of the compartment.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param int limit: (optional)
            For list pagination. The maximum number of results per page, or items to return in a paginated
            \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str page: (optional)
            For list pagination. The value of the `opc-next-page` response header from the previous \"List\"
            call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ocvp.models.SupportedVmwareSoftwareVersionCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/list_supported_vmware_software_versions.py.html>`__ to see an example of how to use list_supported_vmware_software_versions API.
        """
        resource_path = "/supportedVmwareSoftwareVersions"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "limit",
            "page",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_supported_vmware_software_versions got unknown kwargs: {!r}".format(extra_kwargs))

        query_params = {
            "compartmentId": compartment_id,
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="SupportedVmwareSoftwareVersionCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="SupportedVmwareSoftwareVersionCollection")

    def refresh_hcx_license_status(self, sddc_id, **kwargs):
        """
        Refresh HCX on-premise licenses status of the specified SDDC.


        :param str sddc_id: (required)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations (for example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            may be rejected).

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/refresh_hcx_license_status.py.html>`__ to see an example of how to use refresh_hcx_license_status API.
        """
        resource_path = "/sddcs/{sddcId}/actions/refreshHcxLicenses"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "refresh_hcx_license_status got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "sddcId": sddc_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def update_sddc(self, sddc_id, update_sddc_details, **kwargs):
        """
        Updates the specified SDDC.

        **Important:** Updating an SDDC affects only certain attributes in the `Sddc`
        object and does not affect the VMware environment currently running in
        the SDDC. For more information, see
        :func:`update_sddc_details`.


        :param str sddc_id: (required)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.ocvp.models.UpdateSddcDetails update_sddc_details: (required)
            The information to be updated.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ocvp.models.Sddc`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/update_sddc.py.html>`__ to see an example of how to use update_sddc API.
        """
        resource_path = "/sddcs/{sddcId}"
        method = "PUT"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_sddc got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "sddcId": sddc_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_sddc_details,
                response_type="Sddc")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_sddc_details,
                response_type="Sddc")

    def upgrade_hcx(self, sddc_id, **kwargs):
        """
        Upgrade the specified SDDC from HCX Advanced to HCX Enterprise.


        :param str sddc_id: (required)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations (for example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            may be rejected).

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/ocvp/upgrade_hcx.py.html>`__ to see an example of how to use upgrade_hcx API.
        """
        resource_path = "/sddcs/{sddcId}/actions/upgradeHcx"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "upgrade_hcx got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "sddcId": sddc_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateMigrationDetails(object):
    """
    While creating a migration, specify the source and the application that you want migrate.
    Each migration moves a single application from a specified source to a specified Oracle Cloud Infrastructure tenancy.
    If required, provide the credentials of the application administrator in the source environment.
    Application Migration uses this information to access the application, as well as discover application artifacts,
    such as the complete domain configuration along with data sources and other dependencies.

    You must also assign a name and provide a description for the migration.
    This helps you to identify the appropriate source environment when you have multiple sources defined.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the pre_created_target_database_type property of a CreateMigrationDetails.
    #: This constant has a value of "DATABASE_SYSTEM"
    PRE_CREATED_TARGET_DATABASE_TYPE_DATABASE_SYSTEM = "DATABASE_SYSTEM"

    #: A constant which can be used with the pre_created_target_database_type property of a CreateMigrationDetails.
    #: This constant has a value of "NOT_SET"
    PRE_CREATED_TARGET_DATABASE_TYPE_NOT_SET = "NOT_SET"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateMigrationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateMigrationDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateMigrationDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateMigrationDetails.
        :type description: str

        :param source_id:
            The value to assign to the source_id property of this CreateMigrationDetails.
        :type source_id: str

        :param application_name:
            The value to assign to the application_name property of this CreateMigrationDetails.
        :type application_name: str

        :param discovery_details:
            The value to assign to the discovery_details property of this CreateMigrationDetails.
        :type discovery_details: oci.application_migration.models.DiscoveryDetails

        :param pre_created_target_database_type:
            The value to assign to the pre_created_target_database_type property of this CreateMigrationDetails.
            Allowed values for this property are: "DATABASE_SYSTEM", "NOT_SET"
        :type pre_created_target_database_type: str

        :param is_selective_migration:
            The value to assign to the is_selective_migration property of this CreateMigrationDetails.
        :type is_selective_migration: bool

        :param service_config:
            The value to assign to the service_config property of this CreateMigrationDetails.
        :type service_config: dict(str, ConfigurationField)

        :param application_config:
            The value to assign to the application_config property of this CreateMigrationDetails.
        :type application_config: dict(str, ConfigurationField)

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateMigrationDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateMigrationDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'source_id': 'str',
            'application_name': 'str',
            'discovery_details': 'DiscoveryDetails',
            'pre_created_target_database_type': 'str',
            'is_selective_migration': 'bool',
            'service_config': 'dict(str, ConfigurationField)',
            'application_config': 'dict(str, ConfigurationField)',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'source_id': 'sourceId',
            'application_name': 'applicationName',
            'discovery_details': 'discoveryDetails',
            'pre_created_target_database_type': 'preCreatedTargetDatabaseType',
            'is_selective_migration': 'isSelectiveMigration',
            'service_config': 'serviceConfig',
            'application_config': 'applicationConfig',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._source_id = None
        self._application_name = None
        self._discovery_details = None
        self._pre_created_target_database_type = None
        self._is_selective_migration = None
        self._service_config = None
        self._application_config = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateMigrationDetails.
        The `OCID`__ of the compartment that contains the source.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateMigrationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateMigrationDetails.
        The `OCID`__ of the compartment that contains the source.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateMigrationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateMigrationDetails.
        User-friendly name of the application. This will be the name of the migrated application in Oracle Cloud Infrastructure.


        :return: The display_name of this CreateMigrationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateMigrationDetails.
        User-friendly name of the application. This will be the name of the migrated application in Oracle Cloud Infrastructure.


        :param display_name: The display_name of this CreateMigrationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateMigrationDetails.
        Description of the application that you are migrating.


        :return: The description of this CreateMigrationDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateMigrationDetails.
        Description of the application that you are migrating.


        :param description: The description of this CreateMigrationDetails.
        :type: str
        """
        self._description = description

    @property
    def source_id(self):
        """
        **[Required]** Gets the source_id of this CreateMigrationDetails.
        The `OCID`__ of the source.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The source_id of this CreateMigrationDetails.
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this CreateMigrationDetails.
        The `OCID`__ of the source.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param source_id: The source_id of this CreateMigrationDetails.
        :type: str
        """
        self._source_id = source_id

    @property
    def application_name(self):
        """
        **[Required]** Gets the application_name of this CreateMigrationDetails.
        Name of the application that you want to migrate from the source environment.


        :return: The application_name of this CreateMigrationDetails.
        :rtype: str
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        """
        Sets the application_name of this CreateMigrationDetails.
        Name of the application that you want to migrate from the source environment.


        :param application_name: The application_name of this CreateMigrationDetails.
        :type: str
        """
        self._application_name = application_name

    @property
    def discovery_details(self):
        """
        **[Required]** Gets the discovery_details of this CreateMigrationDetails.

        :return: The discovery_details of this CreateMigrationDetails.
        :rtype: oci.application_migration.models.DiscoveryDetails
        """
        return self._discovery_details

    @discovery_details.setter
    def discovery_details(self, discovery_details):
        """
        Sets the discovery_details of this CreateMigrationDetails.

        :param discovery_details: The discovery_details of this CreateMigrationDetails.
        :type: oci.application_migration.models.DiscoveryDetails
        """
        self._discovery_details = discovery_details

    @property
    def pre_created_target_database_type(self):
        """
        Gets the pre_created_target_database_type of this CreateMigrationDetails.
        The pre-existing database type to be used in this migration. Currently, Application migration only supports Oracle Cloud
        Infrastructure databases and this option is currently available only for `JAVA_CLOUD_SERVICE` and `WEBLOGIC_CLOUD_SERVICE` target instance types.

        Allowed values for this property are: "DATABASE_SYSTEM", "NOT_SET"


        :return: The pre_created_target_database_type of this CreateMigrationDetails.
        :rtype: str
        """
        return self._pre_created_target_database_type

    @pre_created_target_database_type.setter
    def pre_created_target_database_type(self, pre_created_target_database_type):
        """
        Sets the pre_created_target_database_type of this CreateMigrationDetails.
        The pre-existing database type to be used in this migration. Currently, Application migration only supports Oracle Cloud
        Infrastructure databases and this option is currently available only for `JAVA_CLOUD_SERVICE` and `WEBLOGIC_CLOUD_SERVICE` target instance types.


        :param pre_created_target_database_type: The pre_created_target_database_type of this CreateMigrationDetails.
        :type: str
        """
        allowed_values = ["DATABASE_SYSTEM", "NOT_SET"]
        if not value_allowed_none_or_none_sentinel(pre_created_target_database_type, allowed_values):
            raise ValueError(
                "Invalid value for `pre_created_target_database_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._pre_created_target_database_type = pre_created_target_database_type

    @property
    def is_selective_migration(self):
        """
        Gets the is_selective_migration of this CreateMigrationDetails.
        If set to `true`, Application Migration migrates the application resources selectively depending on the source.


        :return: The is_selective_migration of this CreateMigrationDetails.
        :rtype: bool
        """
        return self._is_selective_migration

    @is_selective_migration.setter
    def is_selective_migration(self, is_selective_migration):
        """
        Sets the is_selective_migration of this CreateMigrationDetails.
        If set to `true`, Application Migration migrates the application resources selectively depending on the source.


        :param is_selective_migration: The is_selective_migration of this CreateMigrationDetails.
        :type: bool
        """
        self._is_selective_migration = is_selective_migration

    @property
    def service_config(self):
        """
        Gets the service_config of this CreateMigrationDetails.
        Configuration required to migrate the application. In addition to the key and value, additional fields are provided
        to describe type type and purpose of each field. Only the value for each key is required when passing configuration to the
        CreateMigration operation.


        :return: The service_config of this CreateMigrationDetails.
        :rtype: dict(str, ConfigurationField)
        """
        return self._service_config

    @service_config.setter
    def service_config(self, service_config):
        """
        Sets the service_config of this CreateMigrationDetails.
        Configuration required to migrate the application. In addition to the key and value, additional fields are provided
        to describe type type and purpose of each field. Only the value for each key is required when passing configuration to the
        CreateMigration operation.


        :param service_config: The service_config of this CreateMigrationDetails.
        :type: dict(str, ConfigurationField)
        """
        self._service_config = service_config

    @property
    def application_config(self):
        """
        Gets the application_config of this CreateMigrationDetails.
        Configuration required to migrate the application. In addition to the key and value, additional fields are provided
        to describe type type and purpose of each field. Only the value for each key is required when passing configuration to the
        CreateMigration operation.


        :return: The application_config of this CreateMigrationDetails.
        :rtype: dict(str, ConfigurationField)
        """
        return self._application_config

    @application_config.setter
    def application_config(self, application_config):
        """
        Sets the application_config of this CreateMigrationDetails.
        Configuration required to migrate the application. In addition to the key and value, additional fields are provided
        to describe type type and purpose of each field. Only the value for each key is required when passing configuration to the
        CreateMigration operation.


        :param application_config: The application_config of this CreateMigrationDetails.
        :type: dict(str, ConfigurationField)
        """
        self._application_config = application_config

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateMigrationDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__. Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateMigrationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateMigrationDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__. Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateMigrationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateMigrationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__. Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateMigrationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateMigrationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__. Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateMigrationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RecommendationDetails(object):
    """
    Details of a recommendation.
    """

    #: A constant which can be used with the recommendation_type property of a RecommendationDetails.
    #: This constant has a value of "LINK_GLOSSARY_TERM"
    RECOMMENDATION_TYPE_LINK_GLOSSARY_TERM = "LINK_GLOSSARY_TERM"

    #: A constant which can be used with the recommendation_status property of a RecommendationDetails.
    #: This constant has a value of "ACCEPTED"
    RECOMMENDATION_STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the recommendation_status property of a RecommendationDetails.
    #: This constant has a value of "REJECTED"
    RECOMMENDATION_STATUS_REJECTED = "REJECTED"

    #: A constant which can be used with the recommendation_status property of a RecommendationDetails.
    #: This constant has a value of "INFERRED"
    RECOMMENDATION_STATUS_INFERRED = "INFERRED"

    #: A constant which can be used with the source_object_type property of a RecommendationDetails.
    #: This constant has a value of "DATA_ENTITY"
    SOURCE_OBJECT_TYPE_DATA_ENTITY = "DATA_ENTITY"

    #: A constant which can be used with the source_object_type property of a RecommendationDetails.
    #: This constant has a value of "ATTRIBUTE"
    SOURCE_OBJECT_TYPE_ATTRIBUTE = "ATTRIBUTE"

    #: A constant which can be used with the source_object_type property of a RecommendationDetails.
    #: This constant has a value of "TERM"
    SOURCE_OBJECT_TYPE_TERM = "TERM"

    #: A constant which can be used with the source_object_type property of a RecommendationDetails.
    #: This constant has a value of "CATEGORY"
    SOURCE_OBJECT_TYPE_CATEGORY = "CATEGORY"

    #: A constant which can be used with the target_object_type property of a RecommendationDetails.
    #: This constant has a value of "DATA_ENTITY"
    TARGET_OBJECT_TYPE_DATA_ENTITY = "DATA_ENTITY"

    #: A constant which can be used with the target_object_type property of a RecommendationDetails.
    #: This constant has a value of "ATTRIBUTE"
    TARGET_OBJECT_TYPE_ATTRIBUTE = "ATTRIBUTE"

    #: A constant which can be used with the target_object_type property of a RecommendationDetails.
    #: This constant has a value of "TERM"
    TARGET_OBJECT_TYPE_TERM = "TERM"

    #: A constant which can be used with the target_object_type property of a RecommendationDetails.
    #: This constant has a value of "CATEGORY"
    TARGET_OBJECT_TYPE_CATEGORY = "CATEGORY"

    def __init__(self, **kwargs):
        """
        Initializes a new RecommendationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param recommendation_key:
            The value to assign to the recommendation_key property of this RecommendationDetails.
        :type recommendation_key: str

        :param recommendation_type:
            The value to assign to the recommendation_type property of this RecommendationDetails.
            Allowed values for this property are: "LINK_GLOSSARY_TERM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type recommendation_type: str

        :param recommendation_status:
            The value to assign to the recommendation_status property of this RecommendationDetails.
            Allowed values for this property are: "ACCEPTED", "REJECTED", "INFERRED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type recommendation_status: str

        :param confidence_score:
            The value to assign to the confidence_score property of this RecommendationDetails.
        :type confidence_score: float

        :param source_object_key:
            The value to assign to the source_object_key property of this RecommendationDetails.
        :type source_object_key: str

        :param source_object_name:
            The value to assign to the source_object_name property of this RecommendationDetails.
        :type source_object_name: str

        :param source_object_type:
            The value to assign to the source_object_type property of this RecommendationDetails.
            Allowed values for this property are: "DATA_ENTITY", "ATTRIBUTE", "TERM", "CATEGORY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source_object_type: str

        :param target_object_key:
            The value to assign to the target_object_key property of this RecommendationDetails.
        :type target_object_key: str

        :param target_object_name:
            The value to assign to the target_object_name property of this RecommendationDetails.
        :type target_object_name: str

        :param target_object_type:
            The value to assign to the target_object_type property of this RecommendationDetails.
            Allowed values for this property are: "DATA_ENTITY", "ATTRIBUTE", "TERM", "CATEGORY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type target_object_type: str

        :param properties:
            The value to assign to the properties property of this RecommendationDetails.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'recommendation_key': 'str',
            'recommendation_type': 'str',
            'recommendation_status': 'str',
            'confidence_score': 'float',
            'source_object_key': 'str',
            'source_object_name': 'str',
            'source_object_type': 'str',
            'target_object_key': 'str',
            'target_object_name': 'str',
            'target_object_type': 'str',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'recommendation_key': 'recommendationKey',
            'recommendation_type': 'recommendationType',
            'recommendation_status': 'recommendationStatus',
            'confidence_score': 'confidenceScore',
            'source_object_key': 'sourceObjectKey',
            'source_object_name': 'sourceObjectName',
            'source_object_type': 'sourceObjectType',
            'target_object_key': 'targetObjectKey',
            'target_object_name': 'targetObjectName',
            'target_object_type': 'targetObjectType',
            'properties': 'properties'
        }

        self._recommendation_key = None
        self._recommendation_type = None
        self._recommendation_status = None
        self._confidence_score = None
        self._source_object_key = None
        self._source_object_name = None
        self._source_object_type = None
        self._target_object_key = None
        self._target_object_name = None
        self._target_object_type = None
        self._properties = None

    @property
    def recommendation_key(self):
        """
        **[Required]** Gets the recommendation_key of this RecommendationDetails.
        Unique identifier of the recommendation.


        :return: The recommendation_key of this RecommendationDetails.
        :rtype: str
        """
        return self._recommendation_key

    @recommendation_key.setter
    def recommendation_key(self, recommendation_key):
        """
        Sets the recommendation_key of this RecommendationDetails.
        Unique identifier of the recommendation.


        :param recommendation_key: The recommendation_key of this RecommendationDetails.
        :type: str
        """
        self._recommendation_key = recommendation_key

    @property
    def recommendation_type(self):
        """
        **[Required]** Gets the recommendation_type of this RecommendationDetails.
        Type of recommendation.

        Allowed values for this property are: "LINK_GLOSSARY_TERM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The recommendation_type of this RecommendationDetails.
        :rtype: str
        """
        return self._recommendation_type

    @recommendation_type.setter
    def recommendation_type(self, recommendation_type):
        """
        Sets the recommendation_type of this RecommendationDetails.
        Type of recommendation.


        :param recommendation_type: The recommendation_type of this RecommendationDetails.
        :type: str
        """
        allowed_values = ["LINK_GLOSSARY_TERM"]
        if not value_allowed_none_or_none_sentinel(recommendation_type, allowed_values):
            recommendation_type = 'UNKNOWN_ENUM_VALUE'
        self._recommendation_type = recommendation_type

    @property
    def recommendation_status(self):
        """
        **[Required]** Gets the recommendation_status of this RecommendationDetails.
        Status of a recommendation.

        Allowed values for this property are: "ACCEPTED", "REJECTED", "INFERRED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The recommendation_status of this RecommendationDetails.
        :rtype: str
        """
        return self._recommendation_status

    @recommendation_status.setter
    def recommendation_status(self, recommendation_status):
        """
        Sets the recommendation_status of this RecommendationDetails.
        Status of a recommendation.


        :param recommendation_status: The recommendation_status of this RecommendationDetails.
        :type: str
        """
        allowed_values = ["ACCEPTED", "REJECTED", "INFERRED"]
        if not value_allowed_none_or_none_sentinel(recommendation_status, allowed_values):
            recommendation_status = 'UNKNOWN_ENUM_VALUE'
        self._recommendation_status = recommendation_status

    @property
    def confidence_score(self):
        """
        Gets the confidence_score of this RecommendationDetails.
        Level of confidence, on a scale between 0 and 1, that the recommendation is applicable.


        :return: The confidence_score of this RecommendationDetails.
        :rtype: float
        """
        return self._confidence_score

    @confidence_score.setter
    def confidence_score(self, confidence_score):
        """
        Sets the confidence_score of this RecommendationDetails.
        Level of confidence, on a scale between 0 and 1, that the recommendation is applicable.


        :param confidence_score: The confidence_score of this RecommendationDetails.
        :type: float
        """
        self._confidence_score = confidence_score

    @property
    def source_object_key(self):
        """
        Gets the source_object_key of this RecommendationDetails.
        Unique identifier of the source object; the one for which a recommendation is made.


        :return: The source_object_key of this RecommendationDetails.
        :rtype: str
        """
        return self._source_object_key

    @source_object_key.setter
    def source_object_key(self, source_object_key):
        """
        Sets the source_object_key of this RecommendationDetails.
        Unique identifier of the source object; the one for which a recommendation is made.


        :param source_object_key: The source_object_key of this RecommendationDetails.
        :type: str
        """
        self._source_object_key = source_object_key

    @property
    def source_object_name(self):
        """
        Gets the source_object_name of this RecommendationDetails.
        Name of the source object; the one for which a recommendation is made.


        :return: The source_object_name of this RecommendationDetails.
        :rtype: str
        """
        return self._source_object_name

    @source_object_name.setter
    def source_object_name(self, source_object_name):
        """
        Sets the source_object_name of this RecommendationDetails.
        Name of the source object; the one for which a recommendation is made.


        :param source_object_name: The source_object_name of this RecommendationDetails.
        :type: str
        """
        self._source_object_name = source_object_name

    @property
    def source_object_type(self):
        """
        Gets the source_object_type of this RecommendationDetails.
        Type of the source object; the one for which a recommendation is made.

        Allowed values for this property are: "DATA_ENTITY", "ATTRIBUTE", "TERM", "CATEGORY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source_object_type of this RecommendationDetails.
        :rtype: str
        """
        return self._source_object_type

    @source_object_type.setter
    def source_object_type(self, source_object_type):
        """
        Sets the source_object_type of this RecommendationDetails.
        Type of the source object; the one for which a recommendation is made.


        :param source_object_type: The source_object_type of this RecommendationDetails.
        :type: str
        """
        allowed_values = ["DATA_ENTITY", "ATTRIBUTE", "TERM", "CATEGORY"]
        if not value_allowed_none_or_none_sentinel(source_object_type, allowed_values):
            source_object_type = 'UNKNOWN_ENUM_VALUE'
        self._source_object_type = source_object_type

    @property
    def target_object_key(self):
        """
        Gets the target_object_key of this RecommendationDetails.
        Unique identifier of the target object; the one which has been recommended.


        :return: The target_object_key of this RecommendationDetails.
        :rtype: str
        """
        return self._target_object_key

    @target_object_key.setter
    def target_object_key(self, target_object_key):
        """
        Sets the target_object_key of this RecommendationDetails.
        Unique identifier of the target object; the one which has been recommended.


        :param target_object_key: The target_object_key of this RecommendationDetails.
        :type: str
        """
        self._target_object_key = target_object_key

    @property
    def target_object_name(self):
        """
        Gets the target_object_name of this RecommendationDetails.
        Name of the target object; the one which has been recommended.


        :return: The target_object_name of this RecommendationDetails.
        :rtype: str
        """
        return self._target_object_name

    @target_object_name.setter
    def target_object_name(self, target_object_name):
        """
        Sets the target_object_name of this RecommendationDetails.
        Name of the target object; the one which has been recommended.


        :param target_object_name: The target_object_name of this RecommendationDetails.
        :type: str
        """
        self._target_object_name = target_object_name

    @property
    def target_object_type(self):
        """
        Gets the target_object_type of this RecommendationDetails.
        Type of the target object; the one which has been recommended.

        Allowed values for this property are: "DATA_ENTITY", "ATTRIBUTE", "TERM", "CATEGORY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The target_object_type of this RecommendationDetails.
        :rtype: str
        """
        return self._target_object_type

    @target_object_type.setter
    def target_object_type(self, target_object_type):
        """
        Sets the target_object_type of this RecommendationDetails.
        Type of the target object; the one which has been recommended.


        :param target_object_type: The target_object_type of this RecommendationDetails.
        :type: str
        """
        allowed_values = ["DATA_ENTITY", "ATTRIBUTE", "TERM", "CATEGORY"]
        if not value_allowed_none_or_none_sentinel(target_object_type, allowed_values):
            target_object_type = 'UNKNOWN_ENUM_VALUE'
        self._target_object_type = target_object_type

    @property
    def properties(self):
        """
        Gets the properties of this RecommendationDetails.
        A map of maps that contains additional properties which are specific to the associated objects.
        Each associated object defines it's set of required and optional properties.
        Example: `{
                    \"DataEntity\": {
                      \"parentId\": \"entityId\"
                    },
                    \"Term\": {
                      \"parentId\": \"glossaryId\"
                    }
                  }`


        :return: The properties of this RecommendationDetails.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this RecommendationDetails.
        A map of maps that contains additional properties which are specific to the associated objects.
        Each associated object defines it's set of required and optional properties.
        Example: `{
                    \"DataEntity\": {
                      \"parentId\": \"entityId\"
                    },
                    \"Term\": {
                      \"parentId\": \"glossaryId\"
                    }
                  }`


        :param properties: The properties of this RecommendationDetails.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_container_scan_recipe_compartment_details import ChangeContainerScanRecipeCompartmentDetails
from .change_container_scan_result_compartment_details import ChangeContainerScanResultCompartmentDetails
from .change_container_scan_target_compartment_details import ChangeContainerScanTargetCompartmentDetails
from .change_host_agent_scan_result_compartment_details import ChangeHostAgentScanResultCompartmentDetails
from .change_host_cis_benchmark_scan_result_compartment_details import ChangeHostCisBenchmarkScanResultCompartmentDetails
from .change_host_endpoint_protection_scan_result_compartment_details import ChangeHostEndpointProtectionScanResultCompartmentDetails
from .change_host_port_scan_result_compartment_details import ChangeHostPortScanResultCompartmentDetails
from .change_host_scan_recipe_compartment_details import ChangeHostScanRecipeCompartmentDetails
from .change_host_scan_target_compartment_details import ChangeHostScanTargetCompartmentDetails
from .container_scan_recipe import ContainerScanRecipe
from .container_scan_recipe_summary import ContainerScanRecipeSummary
from .container_scan_recipe_summary_collection import ContainerScanRecipeSummaryCollection
from .container_scan_registry import ContainerScanRegistry
from .container_scan_result import ContainerScanResult
from .container_scan_result_problem import ContainerScanResultProblem
from .container_scan_result_summary import ContainerScanResultSummary
from .container_scan_result_summary_collection import ContainerScanResultSummaryCollection
from .container_scan_settings import ContainerScanSettings
from .container_scan_target import ContainerScanTarget
from .container_scan_target_summary import ContainerScanTargetSummary
from .container_scan_target_summary_collection import ContainerScanTargetSummaryCollection
from .create_container_scan_recipe_details import CreateContainerScanRecipeDetails
from .create_container_scan_registry_details import CreateContainerScanRegistryDetails
from .create_container_scan_target_details import CreateContainerScanTargetDetails
from .create_host_scan_recipe_details import CreateHostScanRecipeDetails
from .create_host_scan_target_details import CreateHostScanTargetDetails
from .create_ocir_container_scan_registry_details import CreateOcirContainerScanRegistryDetails
from .cve_details import CveDetails
from .export_host_agent_scan_result_csv_details import ExportHostAgentScanResultCsvDetails
from .export_host_vulnerability_csv_details import ExportHostVulnerabilityCsvDetails
from .host_agent_scan_result import HostAgentScanResult
from .host_agent_scan_result_problem import HostAgentScanResultProblem
from .host_agent_scan_result_summary import HostAgentScanResultSummary
from .host_agent_scan_result_summary_collection import HostAgentScanResultSummaryCollection
from .host_cis_benchmark_scan_result import HostCisBenchmarkScanResult
from .host_cis_benchmark_scan_result_score import HostCisBenchmarkScanResultScore
from .host_cis_benchmark_scan_result_summary import HostCisBenchmarkScanResultSummary
from .host_cis_benchmark_scan_result_summary_collection import HostCisBenchmarkScanResultSummaryCollection
from .host_cis_benchmark_settings import HostCisBenchmarkSettings
from .host_endpoint_protection_scan_result import HostEndpointProtectionScanResult
from .host_endpoint_protection_scan_result_endpoint_protection import HostEndpointProtectionScanResultEndpointProtection
from .host_endpoint_protection_scan_result_summary import HostEndpointProtectionScanResultSummary
from .host_endpoint_protection_scan_result_summary_collection import HostEndpointProtectionScanResultSummaryCollection
from .host_endpoint_protection_settings import HostEndpointProtectionSettings
from .host_port_scan_result import HostPortScanResult
from .host_port_scan_result_open_port import HostPortScanResultOpenPort
from .host_port_scan_result_summary import HostPortScanResultSummary
from .host_port_scan_result_summary_collection import HostPortScanResultSummaryCollection
from .host_scan_agent_configuration import HostScanAgentConfiguration
from .host_scan_agent_configuration_oci import HostScanAgentConfigurationOCI
from .host_scan_agent_settings import HostScanAgentSettings
from .host_scan_port_settings import HostScanPortSettings
from .host_scan_recipe import HostScanRecipe
from .host_scan_recipe_summary import HostScanRecipeSummary
from .host_scan_recipe_summary_collection import HostScanRecipeSummaryCollection
from .host_scan_target import HostScanTarget
from .host_scan_target_summary import HostScanTargetSummary
from .host_scan_target_summary_collection import HostScanTargetSummaryCollection
from .host_vulnerability import HostVulnerability
from .host_vulnerability_impacted_host_summary import HostVulnerabilityImpactedHostSummary
from .host_vulnerability_impacted_host_summary_collection import HostVulnerabilityImpactedHostSummaryCollection
from .host_vulnerability_summary import HostVulnerabilitySummary
from .host_vulnerability_summary_collection import HostVulnerabilitySummaryCollection
from .ocir_container_scan_registry import OcirContainerScanRegistry
from .schedule import Schedule
from .update_container_scan_recipe_details import UpdateContainerScanRecipeDetails
from .update_container_scan_registry_details import UpdateContainerScanRegistryDetails
from .update_container_scan_target_details import UpdateContainerScanTargetDetails
from .update_host_scan_recipe_details import UpdateHostScanRecipeDetails
from .update_host_scan_target_details import UpdateHostScanTargetDetails
from .update_ocir_container_scan_registry_details import UpdateOcirContainerScanRegistryDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource

# Maps type names to classes for vulnerability_scanning services.
vulnerability_scanning_type_mapping = {
    "ChangeContainerScanRecipeCompartmentDetails": ChangeContainerScanRecipeCompartmentDetails,
    "ChangeContainerScanResultCompartmentDetails": ChangeContainerScanResultCompartmentDetails,
    "ChangeContainerScanTargetCompartmentDetails": ChangeContainerScanTargetCompartmentDetails,
    "ChangeHostAgentScanResultCompartmentDetails": ChangeHostAgentScanResultCompartmentDetails,
    "ChangeHostCisBenchmarkScanResultCompartmentDetails": ChangeHostCisBenchmarkScanResultCompartmentDetails,
    "ChangeHostEndpointProtectionScanResultCompartmentDetails": ChangeHostEndpointProtectionScanResultCompartmentDetails,
    "ChangeHostPortScanResultCompartmentDetails": ChangeHostPortScanResultCompartmentDetails,
    "ChangeHostScanRecipeCompartmentDetails": ChangeHostScanRecipeCompartmentDetails,
    "ChangeHostScanTargetCompartmentDetails": ChangeHostScanTargetCompartmentDetails,
    "ContainerScanRecipe": ContainerScanRecipe,
    "ContainerScanRecipeSummary": ContainerScanRecipeSummary,
    "ContainerScanRecipeSummaryCollection": ContainerScanRecipeSummaryCollection,
    "ContainerScanRegistry": ContainerScanRegistry,
    "ContainerScanResult": ContainerScanResult,
    "ContainerScanResultProblem": ContainerScanResultProblem,
    "ContainerScanResultSummary": ContainerScanResultSummary,
    "ContainerScanResultSummaryCollection": ContainerScanResultSummaryCollection,
    "ContainerScanSettings": ContainerScanSettings,
    "ContainerScanTarget": ContainerScanTarget,
    "ContainerScanTargetSummary": ContainerScanTargetSummary,
    "ContainerScanTargetSummaryCollection": ContainerScanTargetSummaryCollection,
    "CreateContainerScanRecipeDetails": CreateContainerScanRecipeDetails,
    "CreateContainerScanRegistryDetails": CreateContainerScanRegistryDetails,
    "CreateContainerScanTargetDetails": CreateContainerScanTargetDetails,
    "CreateHostScanRecipeDetails": CreateHostScanRecipeDetails,
    "CreateHostScanTargetDetails": CreateHostScanTargetDetails,
    "CreateOcirContainerScanRegistryDetails": CreateOcirContainerScanRegistryDetails,
    "CveDetails": CveDetails,
    "ExportHostAgentScanResultCsvDetails": ExportHostAgentScanResultCsvDetails,
    "ExportHostVulnerabilityCsvDetails": ExportHostVulnerabilityCsvDetails,
    "HostAgentScanResult": HostAgentScanResult,
    "HostAgentScanResultProblem": HostAgentScanResultProblem,
    "HostAgentScanResultSummary": HostAgentScanResultSummary,
    "HostAgentScanResultSummaryCollection": HostAgentScanResultSummaryCollection,
    "HostCisBenchmarkScanResult": HostCisBenchmarkScanResult,
    "HostCisBenchmarkScanResultScore": HostCisBenchmarkScanResultScore,
    "HostCisBenchmarkScanResultSummary": HostCisBenchmarkScanResultSummary,
    "HostCisBenchmarkScanResultSummaryCollection": HostCisBenchmarkScanResultSummaryCollection,
    "HostCisBenchmarkSettings": HostCisBenchmarkSettings,
    "HostEndpointProtectionScanResult": HostEndpointProtectionScanResult,
    "HostEndpointProtectionScanResultEndpointProtection": HostEndpointProtectionScanResultEndpointProtection,
    "HostEndpointProtectionScanResultSummary": HostEndpointProtectionScanResultSummary,
    "HostEndpointProtectionScanResultSummaryCollection": HostEndpointProtectionScanResultSummaryCollection,
    "HostEndpointProtectionSettings": HostEndpointProtectionSettings,
    "HostPortScanResult": HostPortScanResult,
    "HostPortScanResultOpenPort": HostPortScanResultOpenPort,
    "HostPortScanResultSummary": HostPortScanResultSummary,
    "HostPortScanResultSummaryCollection": HostPortScanResultSummaryCollection,
    "HostScanAgentConfiguration": HostScanAgentConfiguration,
    "HostScanAgentConfigurationOCI": HostScanAgentConfigurationOCI,
    "HostScanAgentSettings": HostScanAgentSettings,
    "HostScanPortSettings": HostScanPortSettings,
    "HostScanRecipe": HostScanRecipe,
    "HostScanRecipeSummary": HostScanRecipeSummary,
    "HostScanRecipeSummaryCollection": HostScanRecipeSummaryCollection,
    "HostScanTarget": HostScanTarget,
    "HostScanTargetSummary": HostScanTargetSummary,
    "HostScanTargetSummaryCollection": HostScanTargetSummaryCollection,
    "HostVulnerability": HostVulnerability,
    "HostVulnerabilityImpactedHostSummary": HostVulnerabilityImpactedHostSummary,
    "HostVulnerabilityImpactedHostSummaryCollection": HostVulnerabilityImpactedHostSummaryCollection,
    "HostVulnerabilitySummary": HostVulnerabilitySummary,
    "HostVulnerabilitySummaryCollection": HostVulnerabilitySummaryCollection,
    "OcirContainerScanRegistry": OcirContainerScanRegistry,
    "Schedule": Schedule,
    "UpdateContainerScanRecipeDetails": UpdateContainerScanRecipeDetails,
    "UpdateContainerScanRegistryDetails": UpdateContainerScanRegistryDetails,
    "UpdateContainerScanTargetDetails": UpdateContainerScanTargetDetails,
    "UpdateHostScanRecipeDetails": UpdateHostScanRecipeDetails,
    "UpdateHostScanTargetDetails": UpdateHostScanTargetDetails,
    "UpdateOcirContainerScanRegistryDetails": UpdateOcirContainerScanRegistryDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdatePublicationDetails(object):
    """
    The model for the parameters needed to update a publication.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdatePublicationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this UpdatePublicationDetails.
        :type name: str

        :param short_description:
            The value to assign to the short_description property of this UpdatePublicationDetails.
        :type short_description: str

        :param long_description:
            The value to assign to the long_description property of this UpdatePublicationDetails.
        :type long_description: str

        :param support_contacts:
            The value to assign to the support_contacts property of this UpdatePublicationDetails.
        :type support_contacts: list[oci.marketplace.models.SupportContact]

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdatePublicationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdatePublicationDetails.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'name': 'str',
            'short_description': 'str',
            'long_description': 'str',
            'support_contacts': 'list[SupportContact]',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'name': 'name',
            'short_description': 'shortDescription',
            'long_description': 'longDescription',
            'support_contacts': 'supportContacts',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._name = None
        self._short_description = None
        self._long_description = None
        self._support_contacts = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def name(self):
        """
        Gets the name of this UpdatePublicationDetails.
        The name of the publication, which is also used in the listing.


        :return: The name of this UpdatePublicationDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdatePublicationDetails.
        The name of the publication, which is also used in the listing.


        :param name: The name of this UpdatePublicationDetails.
        :type: str
        """
        self._name = name

    @property
    def short_description(self):
        """
        Gets the short_description of this UpdatePublicationDetails.
        A short description of the publication to use in the listing.


        :return: The short_description of this UpdatePublicationDetails.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this UpdatePublicationDetails.
        A short description of the publication to use in the listing.


        :param short_description: The short_description of this UpdatePublicationDetails.
        :type: str
        """
        self._short_description = short_description

    @property
    def long_description(self):
        """
        Gets the long_description of this UpdatePublicationDetails.
        A long description of the publication to use in the listing.


        :return: The long_description of this UpdatePublicationDetails.
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """
        Sets the long_description of this UpdatePublicationDetails.
        A long description of the publication to use in the listing.


        :param long_description: The long_description of this UpdatePublicationDetails.
        :type: str
        """
        self._long_description = long_description

    @property
    def support_contacts(self):
        """
        Gets the support_contacts of this UpdatePublicationDetails.
        Contact information for getting support from the publisher for the listing.


        :return: The support_contacts of this UpdatePublicationDetails.
        :rtype: list[oci.marketplace.models.SupportContact]
        """
        return self._support_contacts

    @support_contacts.setter
    def support_contacts(self, support_contacts):
        """
        Sets the support_contacts of this UpdatePublicationDetails.
        Contact information for getting support from the publisher for the listing.


        :param support_contacts: The support_contacts of this UpdatePublicationDetails.
        :type: list[oci.marketplace.models.SupportContact]
        """
        self._support_contacts = support_contacts

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdatePublicationDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdatePublicationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdatePublicationDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdatePublicationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdatePublicationDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdatePublicationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdatePublicationDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdatePublicationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DrgRouteRule(object):
    """
    A DRG route rule is a mapping between a destination IP address range and a DRG attachment.
    The map is used to route matching packets. Traffic will be routed across the attachments using Equal-cost multi-path routing (ECMP)
    if there are multiple rules with identical destinations and none of the rules conflict.
    """

    #: A constant which can be used with the destination_type property of a DrgRouteRule.
    #: This constant has a value of "CIDR_BLOCK"
    DESTINATION_TYPE_CIDR_BLOCK = "CIDR_BLOCK"

    #: A constant which can be used with the destination_type property of a DrgRouteRule.
    #: This constant has a value of "SERVICE_CIDR_BLOCK"
    DESTINATION_TYPE_SERVICE_CIDR_BLOCK = "SERVICE_CIDR_BLOCK"

    #: A constant which can be used with the route_type property of a DrgRouteRule.
    #: This constant has a value of "STATIC"
    ROUTE_TYPE_STATIC = "STATIC"

    #: A constant which can be used with the route_type property of a DrgRouteRule.
    #: This constant has a value of "DYNAMIC"
    ROUTE_TYPE_DYNAMIC = "DYNAMIC"

    #: A constant which can be used with the route_provenance property of a DrgRouteRule.
    #: This constant has a value of "STATIC"
    ROUTE_PROVENANCE_STATIC = "STATIC"

    #: A constant which can be used with the route_provenance property of a DrgRouteRule.
    #: This constant has a value of "VCN"
    ROUTE_PROVENANCE_VCN = "VCN"

    #: A constant which can be used with the route_provenance property of a DrgRouteRule.
    #: This constant has a value of "VIRTUAL_CIRCUIT"
    ROUTE_PROVENANCE_VIRTUAL_CIRCUIT = "VIRTUAL_CIRCUIT"

    #: A constant which can be used with the route_provenance property of a DrgRouteRule.
    #: This constant has a value of "IPSEC_TUNNEL"
    ROUTE_PROVENANCE_IPSEC_TUNNEL = "IPSEC_TUNNEL"

    def __init__(self, **kwargs):
        """
        Initializes a new DrgRouteRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param destination:
            The value to assign to the destination property of this DrgRouteRule.
        :type destination: str

        :param destination_type:
            The value to assign to the destination_type property of this DrgRouteRule.
            Allowed values for this property are: "CIDR_BLOCK", "SERVICE_CIDR_BLOCK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type destination_type: str

        :param next_hop_drg_attachment_id:
            The value to assign to the next_hop_drg_attachment_id property of this DrgRouteRule.
        :type next_hop_drg_attachment_id: str

        :param route_type:
            The value to assign to the route_type property of this DrgRouteRule.
            Allowed values for this property are: "STATIC", "DYNAMIC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type route_type: str

        :param is_conflict:
            The value to assign to the is_conflict property of this DrgRouteRule.
        :type is_conflict: bool

        :param is_blackhole:
            The value to assign to the is_blackhole property of this DrgRouteRule.
        :type is_blackhole: bool

        :param id:
            The value to assign to the id property of this DrgRouteRule.
        :type id: str

        :param route_provenance:
            The value to assign to the route_provenance property of this DrgRouteRule.
            Allowed values for this property are: "STATIC", "VCN", "VIRTUAL_CIRCUIT", "IPSEC_TUNNEL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type route_provenance: str

        """
        self.swagger_types = {
            'destination': 'str',
            'destination_type': 'str',
            'next_hop_drg_attachment_id': 'str',
            'route_type': 'str',
            'is_conflict': 'bool',
            'is_blackhole': 'bool',
            'id': 'str',
            'route_provenance': 'str'
        }

        self.attribute_map = {
            'destination': 'destination',
            'destination_type': 'destinationType',
            'next_hop_drg_attachment_id': 'nextHopDrgAttachmentId',
            'route_type': 'routeType',
            'is_conflict': 'isConflict',
            'is_blackhole': 'isBlackhole',
            'id': 'id',
            'route_provenance': 'routeProvenance'
        }

        self._destination = None
        self._destination_type = None
        self._next_hop_drg_attachment_id = None
        self._route_type = None
        self._is_conflict = None
        self._is_blackhole = None
        self._id = None
        self._route_provenance = None

    @property
    def destination(self):
        """
        **[Required]** Gets the destination of this DrgRouteRule.
        Represents the range of IP addresses to match against when routing traffic.

        Potential values:
          * An IP address range (IPv4 or IPv6) in CIDR notation. For example: `192.168.1.0/24`
          or `2001:0db8:0123:45::/56`.
          * When you're setting up a security rule for traffic destined for a particular `Service` through
          a service gateway, this is the `cidrBlock` value associated with that :class:`Service`. For example: `oci-phx-objectstorage`.


        :return: The destination of this DrgRouteRule.
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """
        Sets the destination of this DrgRouteRule.
        Represents the range of IP addresses to match against when routing traffic.

        Potential values:
          * An IP address range (IPv4 or IPv6) in CIDR notation. For example: `192.168.1.0/24`
          or `2001:0db8:0123:45::/56`.
          * When you're setting up a security rule for traffic destined for a particular `Service` through
          a service gateway, this is the `cidrBlock` value associated with that :class:`Service`. For example: `oci-phx-objectstorage`.


        :param destination: The destination of this DrgRouteRule.
        :type: str
        """
        self._destination = destination

    @property
    def destination_type(self):
        """
        **[Required]** Gets the destination_type of this DrgRouteRule.
        The type of destination for the rule. the type is required if `direction` = `EGRESS`.

        Allowed values:

          * `CIDR_BLOCK`: If the rule's `destination` is an IP address range in CIDR notation.
          * `SERVICE_CIDR_BLOCK`: If the rule's `destination` is the `cidrBlock` value for a
            :class:`Service` (the rule is for traffic destined for a
            particular `Service` through a service gateway).

        Allowed values for this property are: "CIDR_BLOCK", "SERVICE_CIDR_BLOCK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The destination_type of this DrgRouteRule.
        :rtype: str
        """
        return self._destination_type

    @destination_type.setter
    def destination_type(self, destination_type):
        """
        Sets the destination_type of this DrgRouteRule.
        The type of destination for the rule. the type is required if `direction` = `EGRESS`.

        Allowed values:

          * `CIDR_BLOCK`: If the rule's `destination` is an IP address range in CIDR notation.
          * `SERVICE_CIDR_BLOCK`: If the rule's `destination` is the `cidrBlock` value for a
            :class:`Service` (the rule is for traffic destined for a
            particular `Service` through a service gateway).


        :param destination_type: The destination_type of this DrgRouteRule.
        :type: str
        """
        allowed_values = ["CIDR_BLOCK", "SERVICE_CIDR_BLOCK"]
        if not value_allowed_none_or_none_sentinel(destination_type, allowed_values):
            destination_type = 'UNKNOWN_ENUM_VALUE'
        self._destination_type = destination_type

    @property
    def next_hop_drg_attachment_id(self):
        """
        **[Required]** Gets the next_hop_drg_attachment_id of this DrgRouteRule.
        The `OCID`__ of the next hop DRG attachment responsible
        for reaching the network destination.

        A value of `BLACKHOLE` means traffic for this route is discarded without notification.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The next_hop_drg_attachment_id of this DrgRouteRule.
        :rtype: str
        """
        return self._next_hop_drg_attachment_id

    @next_hop_drg_attachment_id.setter
    def next_hop_drg_attachment_id(self, next_hop_drg_attachment_id):
        """
        Sets the next_hop_drg_attachment_id of this DrgRouteRule.
        The `OCID`__ of the next hop DRG attachment responsible
        for reaching the network destination.

        A value of `BLACKHOLE` means traffic for this route is discarded without notification.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param next_hop_drg_attachment_id: The next_hop_drg_attachment_id of this DrgRouteRule.
        :type: str
        """
        self._next_hop_drg_attachment_id = next_hop_drg_attachment_id

    @property
    def route_type(self):
        """
        Gets the route_type of this DrgRouteRule.
        You can specify static routes for the DRG route table using the API.
        The DRG learns dynamic routes from the DRG attachments using various routing protocols.

        Allowed values for this property are: "STATIC", "DYNAMIC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The route_type of this DrgRouteRule.
        :rtype: str
        """
        return self._route_type

    @route_type.setter
    def route_type(self, route_type):
        """
        Sets the route_type of this DrgRouteRule.
        You can specify static routes for the DRG route table using the API.
        The DRG learns dynamic routes from the DRG attachments using various routing protocols.


        :param route_type: The route_type of this DrgRouteRule.
        :type: str
        """
        allowed_values = ["STATIC", "DYNAMIC"]
        if not value_allowed_none_or_none_sentinel(route_type, allowed_values):
            route_type = 'UNKNOWN_ENUM_VALUE'
        self._route_type = route_type

    @property
    def is_conflict(self):
        """
        Gets the is_conflict of this DrgRouteRule.
        Indicates that the route was not imported due to a conflict between route rules.


        :return: The is_conflict of this DrgRouteRule.
        :rtype: bool
        """
        return self._is_conflict

    @is_conflict.setter
    def is_conflict(self, is_conflict):
        """
        Sets the is_conflict of this DrgRouteRule.
        Indicates that the route was not imported due to a conflict between route rules.


        :param is_conflict: The is_conflict of this DrgRouteRule.
        :type: bool
        """
        self._is_conflict = is_conflict

    @property
    def is_blackhole(self):
        """
        Gets the is_blackhole of this DrgRouteRule.
        Indicates that if the next hop attachment does not exist, so traffic for this route is discarded without notification.


        :return: The is_blackhole of this DrgRouteRule.
        :rtype: bool
        """
        return self._is_blackhole

    @is_blackhole.setter
    def is_blackhole(self, is_blackhole):
        """
        Sets the is_blackhole of this DrgRouteRule.
        Indicates that if the next hop attachment does not exist, so traffic for this route is discarded without notification.


        :param is_blackhole: The is_blackhole of this DrgRouteRule.
        :type: bool
        """
        self._is_blackhole = is_blackhole

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DrgRouteRule.
        The Oracle-assigned ID of the DRG route rule.


        :return: The id of this DrgRouteRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DrgRouteRule.
        The Oracle-assigned ID of the DRG route rule.


        :param id: The id of this DrgRouteRule.
        :type: str
        """
        self._id = id

    @property
    def route_provenance(self):
        """
        **[Required]** Gets the route_provenance of this DrgRouteRule.
        The earliest origin of a route. If a route is advertised to a DRG through an IPsec tunnel attachment,
        and is propagated to peered DRGs via RPC attachments, the route's provenance in the peered DRGs remains `IPSEC_TUNNEL`,
        because that is the earliest origin.

        No routes with a provenance `IPSEC_TUNNEL` or `VIRTUAL_CIRCUIT` will be exported to IPsec tunnel or virtual circuit attachments,
        regardless of the attachment's export distribution.

        Allowed values for this property are: "STATIC", "VCN", "VIRTUAL_CIRCUIT", "IPSEC_TUNNEL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The route_provenance of this DrgRouteRule.
        :rtype: str
        """
        return self._route_provenance

    @route_provenance.setter
    def route_provenance(self, route_provenance):
        """
        Sets the route_provenance of this DrgRouteRule.
        The earliest origin of a route. If a route is advertised to a DRG through an IPsec tunnel attachment,
        and is propagated to peered DRGs via RPC attachments, the route's provenance in the peered DRGs remains `IPSEC_TUNNEL`,
        because that is the earliest origin.

        No routes with a provenance `IPSEC_TUNNEL` or `VIRTUAL_CIRCUIT` will be exported to IPsec tunnel or virtual circuit attachments,
        regardless of the attachment's export distribution.


        :param route_provenance: The route_provenance of this DrgRouteRule.
        :type: str
        """
        allowed_values = ["STATIC", "VCN", "VIRTUAL_CIRCUIT", "IPSEC_TUNNEL"]
        if not value_allowed_none_or_none_sentinel(route_provenance, allowed_values):
            route_provenance = 'UNKNOWN_ENUM_VALUE'
        self._route_provenance = route_provenance

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateAutonomousContainerDatabaseDetails(object):
    """
    Describes the modification parameters for the Autonomous Container Database.
    """

    #: A constant which can be used with the patch_model property of a UpdateAutonomousContainerDatabaseDetails.
    #: This constant has a value of "RELEASE_UPDATES"
    PATCH_MODEL_RELEASE_UPDATES = "RELEASE_UPDATES"

    #: A constant which can be used with the patch_model property of a UpdateAutonomousContainerDatabaseDetails.
    #: This constant has a value of "RELEASE_UPDATE_REVISIONS"
    PATCH_MODEL_RELEASE_UPDATE_REVISIONS = "RELEASE_UPDATE_REVISIONS"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateAutonomousContainerDatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateAutonomousContainerDatabaseDetails.
        :type display_name: str

        :param patch_model:
            The value to assign to the patch_model property of this UpdateAutonomousContainerDatabaseDetails.
            Allowed values for this property are: "RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS"
        :type patch_model: str

        :param maintenance_window_details:
            The value to assign to the maintenance_window_details property of this UpdateAutonomousContainerDatabaseDetails.
        :type maintenance_window_details: oci.database.models.MaintenanceWindow

        :param standby_maintenance_buffer_in_days:
            The value to assign to the standby_maintenance_buffer_in_days property of this UpdateAutonomousContainerDatabaseDetails.
        :type standby_maintenance_buffer_in_days: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateAutonomousContainerDatabaseDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateAutonomousContainerDatabaseDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param backup_config:
            The value to assign to the backup_config property of this UpdateAutonomousContainerDatabaseDetails.
        :type backup_config: oci.database.models.AutonomousContainerDatabaseBackupConfig

        """
        self.swagger_types = {
            'display_name': 'str',
            'patch_model': 'str',
            'maintenance_window_details': 'MaintenanceWindow',
            'standby_maintenance_buffer_in_days': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'backup_config': 'AutonomousContainerDatabaseBackupConfig'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'patch_model': 'patchModel',
            'maintenance_window_details': 'maintenanceWindowDetails',
            'standby_maintenance_buffer_in_days': 'standbyMaintenanceBufferInDays',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'backup_config': 'backupConfig'
        }

        self._display_name = None
        self._patch_model = None
        self._maintenance_window_details = None
        self._standby_maintenance_buffer_in_days = None
        self._freeform_tags = None
        self._defined_tags = None
        self._backup_config = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateAutonomousContainerDatabaseDetails.
        The display name for the Autonomous Container Database.


        :return: The display_name of this UpdateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateAutonomousContainerDatabaseDetails.
        The display name for the Autonomous Container Database.


        :param display_name: The display_name of this UpdateAutonomousContainerDatabaseDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def patch_model(self):
        """
        Gets the patch_model of this UpdateAutonomousContainerDatabaseDetails.
        Database Patch model preference.

        Allowed values for this property are: "RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS"


        :return: The patch_model of this UpdateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._patch_model

    @patch_model.setter
    def patch_model(self, patch_model):
        """
        Sets the patch_model of this UpdateAutonomousContainerDatabaseDetails.
        Database Patch model preference.


        :param patch_model: The patch_model of this UpdateAutonomousContainerDatabaseDetails.
        :type: str
        """
        allowed_values = ["RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS"]
        if not value_allowed_none_or_none_sentinel(patch_model, allowed_values):
            raise ValueError(
                "Invalid value for `patch_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._patch_model = patch_model

    @property
    def maintenance_window_details(self):
        """
        Gets the maintenance_window_details of this UpdateAutonomousContainerDatabaseDetails.

        :return: The maintenance_window_details of this UpdateAutonomousContainerDatabaseDetails.
        :rtype: oci.database.models.MaintenanceWindow
        """
        return self._maintenance_window_details

    @maintenance_window_details.setter
    def maintenance_window_details(self, maintenance_window_details):
        """
        Sets the maintenance_window_details of this UpdateAutonomousContainerDatabaseDetails.

        :param maintenance_window_details: The maintenance_window_details of this UpdateAutonomousContainerDatabaseDetails.
        :type: oci.database.models.MaintenanceWindow
        """
        self._maintenance_window_details = maintenance_window_details

    @property
    def standby_maintenance_buffer_in_days(self):
        """
        Gets the standby_maintenance_buffer_in_days of this UpdateAutonomousContainerDatabaseDetails.
        The scheduling detail for the quarterly maintenance window of the standby Autonomous Container Database.
        This value represents the number of days before schedlued maintenance of the primary database.


        :return: The standby_maintenance_buffer_in_days of this UpdateAutonomousContainerDatabaseDetails.
        :rtype: int
        """
        return self._standby_maintenance_buffer_in_days

    @standby_maintenance_buffer_in_days.setter
    def standby_maintenance_buffer_in_days(self, standby_maintenance_buffer_in_days):
        """
        Sets the standby_maintenance_buffer_in_days of this UpdateAutonomousContainerDatabaseDetails.
        The scheduling detail for the quarterly maintenance window of the standby Autonomous Container Database.
        This value represents the number of days before schedlued maintenance of the primary database.


        :param standby_maintenance_buffer_in_days: The standby_maintenance_buffer_in_days of this UpdateAutonomousContainerDatabaseDetails.
        :type: int
        """
        self._standby_maintenance_buffer_in_days = standby_maintenance_buffer_in_days

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateAutonomousContainerDatabaseDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateAutonomousContainerDatabaseDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateAutonomousContainerDatabaseDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateAutonomousContainerDatabaseDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateAutonomousContainerDatabaseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateAutonomousContainerDatabaseDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateAutonomousContainerDatabaseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateAutonomousContainerDatabaseDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def backup_config(self):
        """
        Gets the backup_config of this UpdateAutonomousContainerDatabaseDetails.

        :return: The backup_config of this UpdateAutonomousContainerDatabaseDetails.
        :rtype: oci.database.models.AutonomousContainerDatabaseBackupConfig
        """
        return self._backup_config

    @backup_config.setter
    def backup_config(self, backup_config):
        """
        Sets the backup_config of this UpdateAutonomousContainerDatabaseDetails.

        :param backup_config: The backup_config of this UpdateAutonomousContainerDatabaseDetails.
        :type: oci.database.models.AutonomousContainerDatabaseBackupConfig
        """
        self._backup_config = backup_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateManagementAgentInstallKeyDetails(object):
    """
    Details required to change Management Agent install key.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateManagementAgentInstallKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_key_active:
            The value to assign to the is_key_active property of this UpdateManagementAgentInstallKeyDetails.
        :type is_key_active: bool

        :param display_name:
            The value to assign to the display_name property of this UpdateManagementAgentInstallKeyDetails.
        :type display_name: str

        """
        self.swagger_types = {
            'is_key_active': 'bool',
            'display_name': 'str'
        }

        self.attribute_map = {
            'is_key_active': 'isKeyActive',
            'display_name': 'displayName'
        }

        self._is_key_active = None
        self._display_name = None

    @property
    def is_key_active(self):
        """
        Gets the is_key_active of this UpdateManagementAgentInstallKeyDetails.
        if set to true the install key state would be set to Active and if false to Inactive


        :return: The is_key_active of this UpdateManagementAgentInstallKeyDetails.
        :rtype: bool
        """
        return self._is_key_active

    @is_key_active.setter
    def is_key_active(self, is_key_active):
        """
        Sets the is_key_active of this UpdateManagementAgentInstallKeyDetails.
        if set to true the install key state would be set to Active and if false to Inactive


        :param is_key_active: The is_key_active of this UpdateManagementAgentInstallKeyDetails.
        :type: bool
        """
        self._is_key_active = is_key_active

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateManagementAgentInstallKeyDetails.
        New displayName of Agent install key.


        :return: The display_name of this UpdateManagementAgentInstallKeyDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateManagementAgentInstallKeyDetails.
        New displayName of Agent install key.


        :param display_name: The display_name of this UpdateManagementAgentInstallKeyDetails.
        :type: str
        """
        self._display_name = display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_details import DatabaseDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseCloudServiceDetails(DatabaseDetails):
    """
    The details of the Oracle Database Cloud Service to be registered as a target database in Data Safe.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseCloudServiceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.DatabaseCloudServiceDetails.database_type` attribute
        of this class is ``DATABASE_CLOUD_SERVICE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_type:
            The value to assign to the database_type property of this DatabaseCloudServiceDetails.
            Allowed values for this property are: "DATABASE_CLOUD_SERVICE", "AUTONOMOUS_DATABASE", "INSTALLED_DATABASE"
        :type database_type: str

        :param infrastructure_type:
            The value to assign to the infrastructure_type property of this DatabaseCloudServiceDetails.
            Allowed values for this property are: "ORACLE_CLOUD", "CLOUD_AT_CUSTOMER", "ON_PREMISES", "NON_ORACLE_CLOUD"
        :type infrastructure_type: str

        :param vm_cluster_id:
            The value to assign to the vm_cluster_id property of this DatabaseCloudServiceDetails.
        :type vm_cluster_id: str

        :param db_system_id:
            The value to assign to the db_system_id property of this DatabaseCloudServiceDetails.
        :type db_system_id: str

        :param service_name:
            The value to assign to the service_name property of this DatabaseCloudServiceDetails.
        :type service_name: str

        """
        self.swagger_types = {
            'database_type': 'str',
            'infrastructure_type': 'str',
            'vm_cluster_id': 'str',
            'db_system_id': 'str',
            'service_name': 'str'
        }

        self.attribute_map = {
            'database_type': 'databaseType',
            'infrastructure_type': 'infrastructureType',
            'vm_cluster_id': 'vmClusterId',
            'db_system_id': 'dbSystemId',
            'service_name': 'serviceName'
        }

        self._database_type = None
        self._infrastructure_type = None
        self._vm_cluster_id = None
        self._db_system_id = None
        self._service_name = None
        self._database_type = 'DATABASE_CLOUD_SERVICE'

    @property
    def vm_cluster_id(self):
        """
        Gets the vm_cluster_id of this DatabaseCloudServiceDetails.
        The OCID of the VM cluster in which the database is running.


        :return: The vm_cluster_id of this DatabaseCloudServiceDetails.
        :rtype: str
        """
        return self._vm_cluster_id

    @vm_cluster_id.setter
    def vm_cluster_id(self, vm_cluster_id):
        """
        Sets the vm_cluster_id of this DatabaseCloudServiceDetails.
        The OCID of the VM cluster in which the database is running.


        :param vm_cluster_id: The vm_cluster_id of this DatabaseCloudServiceDetails.
        :type: str
        """
        self._vm_cluster_id = vm_cluster_id

    @property
    def db_system_id(self):
        """
        Gets the db_system_id of this DatabaseCloudServiceDetails.
        The OCID of the cloud database system registered as a target database in Data Safe.


        :return: The db_system_id of this DatabaseCloudServiceDetails.
        :rtype: str
        """
        return self._db_system_id

    @db_system_id.setter
    def db_system_id(self, db_system_id):
        """
        Sets the db_system_id of this DatabaseCloudServiceDetails.
        The OCID of the cloud database system registered as a target database in Data Safe.


        :param db_system_id: The db_system_id of this DatabaseCloudServiceDetails.
        :type: str
        """
        self._db_system_id = db_system_id

    @property
    def service_name(self):
        """
        Gets the service_name of this DatabaseCloudServiceDetails.
        The database service name.


        :return: The service_name of this DatabaseCloudServiceDetails.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this DatabaseCloudServiceDetails.
        The database service name.


        :param service_name: The service_name of this DatabaseCloudServiceDetails.
        :type: str
        """
        self._service_name = service_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetricDimensionDefinition(object):
    """
    The metric dimension details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MetricDimensionDefinition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dimension_name:
            The value to assign to the dimension_name property of this MetricDimensionDefinition.
        :type dimension_name: str

        :param dimension_value:
            The value to assign to the dimension_value property of this MetricDimensionDefinition.
        :type dimension_value: str

        """
        self.swagger_types = {
            'dimension_name': 'str',
            'dimension_value': 'str'
        }

        self.attribute_map = {
            'dimension_name': 'dimensionName',
            'dimension_value': 'dimensionValue'
        }

        self._dimension_name = None
        self._dimension_value = None

    @property
    def dimension_name(self):
        """
        Gets the dimension_name of this MetricDimensionDefinition.
        The name of the dimension.


        :return: The dimension_name of this MetricDimensionDefinition.
        :rtype: str
        """
        return self._dimension_name

    @dimension_name.setter
    def dimension_name(self, dimension_name):
        """
        Sets the dimension_name of this MetricDimensionDefinition.
        The name of the dimension.


        :param dimension_name: The dimension_name of this MetricDimensionDefinition.
        :type: str
        """
        self._dimension_name = dimension_name

    @property
    def dimension_value(self):
        """
        Gets the dimension_value of this MetricDimensionDefinition.
        The value of the dimension.


        :return: The dimension_value of this MetricDimensionDefinition.
        :rtype: str
        """
        return self._dimension_value

    @dimension_value.setter
    def dimension_value(self, dimension_value):
        """
        Sets the dimension_value of this MetricDimensionDefinition.
        The value of the dimension.


        :param dimension_value: The dimension_value of this MetricDimensionDefinition.
        :type: str
        """
        self._dimension_value = dimension_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
